import gi
gi.require_version ('Astroid', '0.2')
gi.require_version ('Gtk', '3.0')
from gi.repository import GObject, Gtk, Astroid

print ("threadindexplugin: plugin loading..")

class ThreadIndexPlugin (GObject.Object, Astroid.ThreadIndexActivatable):
  thread_index  = GObject.property (type = Gtk.Box)

  def do_activate (self):
    print ('tagformat: activate')
    self.label = Gtk.Label ("Hullu!")
    self.thread_index.pack_end (self.label, True, True, 5)


  def do_deactivate (self):
    print ('tagformat: deactivate')

  def do_format_tags (self, bg, tags, selected):

    from IPython import embed
    # embed ()

    print ("got tags: ", tags)

    return ", ".join (tags)




#! /usr/bin/env python
#
# get keybindings from calls to register_key
#
# Author: Gaute Hope <eg@gaute.vetsj.com> / 2016-02-07
# Author: M. Dietrich <mdt@pyneo.org> / 2016-02-24
#
from __future__ import with_statement, print_function
from re import compile as re_compile
import os
import sys

def stripper(s):
	# bad hack to strip cc string " and brackets for arrays
	if s is None:
		return ''
	if s[0] == '"' and s[-1] == '"':
		return s[1:-1].strip()
	if s[0] == '{' and s[-1] == '}':
		return s[1:-1].strip()
	return s

def out_binding(multi, key, function, documentation, ):
	if 'UnboundKey' in key:
		multi = ', no defaults.'
	else:
		key  = stripper(key)
		if multi:
			multi = ', default: ' + key + ', ' + stripper(multi)
		else:
			multi = ', default: ' + key
	print('#', stripper(function) + '=' + key, '#', stripper(documentation) + multi)

def main(*options):
	# pattern to look for:
	pattern = re_compile("((->|\.)register_key *\([^;]*)")
	# quite mode?
	quiet = True
	for option in options:
		if '-d' == option:
			quiet = False
	# detect src root
	src_root = os.path.join(os.path.dirname(__file__), '../src')
	if not quiet:
		sys.stderr.write("source root: %s\n" % src_root)
	# walk through
	for dname, sdirs, flist in os.walk(src_root):
		for fname in flist:
			_, fext = os.path.splitext(fname)
			# consider cc source
			if fext == '.cc':
				fname = os.path.join(dname, fname)
				if not quiet:
					sys.stderr.write('checking: %s\n' % fname)
				# read whole file
				with open(fname, 'r') as fd:
					txt = fd.read()
				# unify
				txt = txt.replace('\n', ' ')
				txt = txt.replace('\t', ' ')
				# seach pattern
				for group in pattern.findall(txt):
					# only the pattern, not the inbetween
					group, _ = group
					# split args
					args = group.split(', ')
					# strip all whitespaces
					args = list([n.strip() for n in args])
					# cut away function call in the beginning
					args[0] = args[0].split('(',1)[1]
					# detect args in first arg
					if '(' in args[0]:
						while not ')' in args[0]:
							args[0] += ', ' + args.pop(1)
					# detect if mode 1 or 2 of method is used
					if args[1][0] == '"':
						# clear thing, 3-part 1:1 mapping
						out_binding(None, *args[:3])
					elif args[1][0] == '{':
						# multi mapping
						multi = args.pop(1)
						while not '}' in multi:
							multi += ', ' + args.pop(1)
						out_binding(multi, *args[:3])
					else:
						# undetected second param
						print('# not detected', args)

if __name__ == '__main__':
	main(*sys.argv[1:])



import gi
gi.require_version ('Astroid', '0.2')
from gi.repository import GObject, Astroid

print ("basic: plugin loading..")

class BasicPlugin (GObject.Object, Astroid.Activatable):
  object = GObject.property (type=GObject.Object)

  def do_activate (self):
    print ('basic: activate')

  def do_deactivate (self):
    print ('basic: deactivate')

  def do_get_avatar_uri (self, email, tpe, size):
    print ("getting avatar uri", email, tpe, size)
    return "https://assets-cdn.github.com/images/modules/site/infinity-ill-small.png"

  def do_get_allowed_uris (self):
    return ["asdf", "https://assets-cdn.github.com/images/modules/site/"]

